@@ -28,8 +28,6 @@ False
 >>> d3.get_rat_value()
 (Rat 7/24)
 """
-if __name__ == "__main__":
-    import testsetup
 
 from rat import Rat
 
@@ -69,9 +67,3 @@ class Duration:
     def __str__(self):
         return "(Duration:%s:%idot:%s)" % (self.m_nh, self.m_dots, self.m_tuple)
 
-def _test():
-    import doctest, duration
-    return doctest.testmod(duration)
-
-if __name__ == "__main__":
-    _test()
