@@ -23,7 +23,6 @@ a minor third. If you don't require this you can probably
 ise the simpler function mpdutils.int_to_intervalname
 """
 
-import unittest
 import re
 import _exceptions
 
@@ -81,8 +80,9 @@ if 0:
 
 
 class InvalidIntervalnameException(_exceptions.MpdException):
-    def __init__(self, n):
-        self.m_intervalname = n
+    def __init__(self, notename):
+        _exceptions.MpdException.__init__(self)
+        self.m_intervalname = notename
     def __str__(self):
         return _("Invalid interval name: %s") % self.m_intervalname
 
@@ -97,7 +97,7 @@ class Interval:
       m_mod
     should NOT be touched by anyone, except MusicalPitch.__add__
     """
-    __nn_to_interval_quality = {
+    _nn_to_interval_quality = {
         'p': 'perfect',
         'dd': 'doubly-diminished',
         'd': 'diminished',
@@ -120,14 +120,15 @@ class Interval:
         self.m_mod = 0
         if iname:
             self.set_from_string(iname)
-    def nn_to_translated_quality(nn):
+    def nn_to_translated_quality(interval_quality):
         """
-        Return a translated string of the short 1 or 2 char string
-        in nn. Possible values for nn are: dd, d, m, M, a, aa, p
+        Return translated interval quality from internal short string.
+        interval_quality can be: dd, d, m, M, a, a, p
+        The C locale will return english names, as 'perfect' and 'diminished'
         """
         # Hack, just to xgettext should not grab the string for translation
-        xx = _i
-        return xx("interval|%s" % Interval.__nn_to_interval_quality[nn])
+        xgettext_wont_find_us = _i
+        return xgettext_wont_find_us("interval|%s" % Interval._nn_to_interval_quality[interval_quality])
     nn_to_translated_quality = staticmethod(nn_to_translated_quality)
     def number_name(steps):
         try:
@@ -206,7 +207,7 @@ class Interval:
         m = re.match("(m|M|d|a|p)(\d+)", s)
         if not m:
             raise InvalidIntervalnameException(s_orig)
-        n, i = m.groups()
+        modifier, i = m.groups()
         i = int(i)
         if i <= 7:
             self.m_octave = 0
@@ -215,12 +216,12 @@ class Interval:
         self.m_interval = i - 1 - self.m_octave * 7
         if self.m_interval in (1, 2, 5, 6):
             try:
-                self.m_mod = {'d': -2, 'm': -1, 'M': 0, 'a': 1}[n]
+                self.m_mod = {'d': -2, 'm': -1, 'M': 0, 'a': 1}[modifier]
             except:
                 raise InvalidIntervalnameException(s_orig)
         elif self.m_interval in (0, 3, 4):
             try:
-                self.m_mod = {'d': -1, 'p': 0, '': 0, 'a': 1}[n]
+                self.m_mod = {'d': -1, 'p': 0, '': 0, 'a': 1}[modifier]
             except:
                 raise InvalidIntervalnameException(s_orig)
     def get_intvalue(self):
@@ -230,20 +231,21 @@ class Interval:
     def __str__(self):
         if __debug__:
             self.errorcheck()
-        s = "(Interval %i %imod %io" % (self.m_interval, self.m_mod, self.m_octave)
+        ret = "(Interval %i %imod %io" % (self.m_interval, self.m_mod, self.m_octave)
         if self.m_dir == -1:
-            s = s + " down)"
+            ret = ret + " down)"
         else:
-            s = s + " up)"
-        return s
+            ret = ret + " up)"
+        return ret
     def __repr__(self):
         if self.m_interval in (0, 3, 4):
-            mod = {-2: 'dd', -1: 'd', 0: 'p', 1: 'a', 2: 'aa'}
             return "%s%s" % ({-2: 'dd', -1: 'd', 0: 'p', 1: 'a', 2: 'aa'}[self.m_mod], self.m_interval + 1 + self.m_octave * 7)
         return "%s%s" % ({-2: 'd', -1: 'm', 0: 'M', 1: 'a'}[self.m_mod],  (self.m_interval + 1 + self.m_octave * 7))
-    def __eq__(self, b):
-        return self.m_dir == b.m_dir and self.m_octave == b.m_octave \
-            and self.m_mod == b.m_mod and self.m_interval == b.m_interval
+    def __eq__(self, interval):
+        return self.m_dir == interval.m_dir \
+            and self.m_octave == interval.m_octave \
+            and self.m_mod == interval.m_mod \
+            and self.m_interval == interval.m_interval
     def get_number_name(self):
         """
         Return the translated general name of the interval, like second, third
@@ -272,7 +274,7 @@ class Interval:
         """
         Return the non-translated interval quality.
         """
-        return self.__nn_to_interval_quality[self.get_quality_short()]
+        return self._nn_to_interval_quality[self.get_quality_short()]
     def get_cname(self):
         """
         Return the full untranslated interval name, both the number and quality.
@@ -287,43 +289,4 @@ class Interval:
         return self.m_octave * 7 + self.m_interval + 1
 
 
-class TestInterval(unittest.TestCase):
-    def test_constructor(self):
-        for s, a, b, c, i, steps in (
-                ('p1', 0, 0, 0, 0, 1),
-                ('d1', 0, 0, -1, -1, 1),
-                ('a1', 0, 0, 1, 1, 1),
-                ('p4', 3, 0, 0, 5, 4),
-                ('p5', 4, 0, 0, 7, 5),
-                ('p8', 0, 1, 0, 12, 8),
-                ('d8', 0, 1, -1, 11, 8),
-                ('a8', 0, 1, 1, 13, 8),
-                ('p11', 3, 1, 0, 17, 11), # octave + fourth
-                ('p12', 4, 1, 0, 19, 12), # octave + fifth
-                ('p15', 0, 2, 0, 24, 15), # 2*octave
-                ('d15', 0, 2, -1, 23, 15), # 2*octave
-                ('a15', 0, 2, 1, 25, 15), # 2*octave
-                ('m2', 1, 0, -1, 1, 2),
-                ('M2', 1, 0, 0, 2, 2),
-                ('M3', 2, 0, 0, 4, 3),
-                ('M6', 5, 0, 0, 9, 6),
-                ('M9', 1, 1, 0, 14, 9),
-                ('m10', 2, 1, -1, 15, 10), # decim
-                ('M13', 5, 1, 0, 21, 13), # octave + sixth
-                ('m14', 6, 1, -1, 22, 14), # octave + seventh
-                ('M16', 1, 2, 0, 26, 16), # 2*octave + second
-                ):
-            n = Interval(s)
-            self.assertEquals((n.m_interval, n.m_octave, n.m_mod), (a, b, c))
-            self.assertEquals(repr(n), s)
-            self.assertEquals(i, n.get_intvalue())
-            self.assertEquals(steps, n.steps())
-    def test_addition(self):
-        from musicalpitch import MusicalPitch
-        a = MusicalPitch.new_from_notename("c'")
-        b = Interval("m2")
-        self.assertEquals((a+b).get_octave_notename(), "des'")
 
-if __name__ == "__main__":
-    import testsetup
-    unittest.main()
