@@ -19,8 +19,6 @@
 Only utility functions and classes that are private to the mpd module
 should go into this file.
 """
-if __name__ == "__main__":
-    import testsetup
 
 from musicalpitch import MusicalPitch
 import _exceptions
