@@ -32,8 +32,18 @@ if not os.path.exists(src.gethomedir.get_home_dir()):
 if sys.platform == 'win32':
     print "Using as home dir:", src.gethomedir.get_home_dir()
 
-src.cfg.initialise("default.config", None,
+try:
+    src.cfg.initialise("default.config", None,
                    os.path.join(src.gethomedir.get_home_dir(), ".solfegerc"))
+except UnicodeDecodeError, e:
+    import traceback
+    traceback.print_exc()
+    print "\n\tYou .solfegerc file is not properly utf8 encoded. Most likely"
+    print "\tit is the path to some external program that contain non-ascii"
+    print "\tcharacters. Please edit or delete the file. Or email it to"
+    print "\ttca@gnu.org, and he will tell you what the problem is.\n"
+    sys.exit(-1)
+
 
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
