@@ -17,6 +17,7 @@
 
 import oss_common
 import solfege_c_midi
+from mpd.track import MidiEventStream
 import os
 
 class OSSSequencerSynth(oss_common.AbstractSynth):
@@ -92,14 +93,16 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
         return voice
     def set_patch(self, chan, patch):
         self.m_channel_patches[chan] = patch
-    def play_track(self, track):
+    def play_track(self, *tracks):
+        self.play_midieventstream(MidiEventStream(*tracks))
+    def play_midieventstream(self, midieventstream):
         solfege_c_midi.sndctl_seq_reset()
         self.reset()
         solfege_c_midi.seq_start_timer()
-        for e in track.m_v:
-            if e[0] == track.TEMPO:
+        for e in midieventstream:
+            if e[0] == midieventstream.TEMPO:
                 self.__tempo = (e[1], e[2])
-            elif e[0] == track.NOTE_ON:
+            elif e[0] == midieventstream.NOTE_ON:
                 channel, note, vel = e[1:4]
                 voice = self.alloc_voice(channel, note)
                 if voice is not None:
@@ -108,7 +111,7 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
                     if channel == 9:#voice == 31:
                         voice = 9
                     solfege_c_midi.seq_start_note(self.m_devnum, voice, note, vel)
-            elif e[0] == track.NOTE_OFF:
+            elif e[0] == midieventstream.NOTE_OFF:
                 channel, note, vel = e[1:4]
                 voice = self.free_voice(channel, note)
                 if voice is not None:
@@ -116,13 +119,13 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
                     if channel == 9:#voice == 31:
                         voice = 9
                     solfege_c_midi.seq_stop_note(self.m_devnum, voice, note, vel)
-            elif e[0] == track.NOTELEN_TIME:
+            elif e[0] == midieventstream.NOTELEN_TIME:
                 # 96 is a const, also used in soundcard.initialize that
                 # I don't understand.
                 solfege_c_midi.seq_delta_time(int(int(96*e[1]) * 60.0 * self.__tempo[1] / self.__tempo[0]))
-            elif e[0] == track.SET_PATCH:
+            elif e[0] == midieventstream.SET_PATCH:
                 self.set_patch(e[1], e[2])
-            elif e[0] == track.BENDER:
+            elif e[0] == midieventstream.BENDER:
                 print "FIXME: DevSequencerSynth.BENDER"
                 #solfege_d_midi.seq_bender(self.m_devnum, e[1], e[2])
             else:
