@@ -16,11 +16,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
+from synth_common import SynthCommon
+from mpd.track import MidiEventStream
 import winmidi
 
-class WinSynth:
+class WinSynth(SynthCommon):
     NUM_CHANNELS = 16
     def __init__(self, devnum, verbose_init):
+        SynthCommon.__init__(self)
         try:
             self.__driver = winmidi.Winmidi(devnum)
         except RuntimeError, e:
@@ -35,7 +38,9 @@ class WinSynth:
     def stop(self):
         # dummy function
         pass
-    def play_track(self, track):
+    def play_track(self, *tracks):
+        self.play_midieventstream(MidiEventStream(*tracks))
+    def play_midieventstream(self, midieventstream):
         if self.__driver is None:
             raise RuntimeError, "Attempted to use synth after closing."
         self.__driver.reset()
@@ -44,21 +49,21 @@ class WinSynth:
         self.__driver.set_tempo(int(magic * 4 / 60))
         v = []
         notelen = 0
-        for e in track.m_v:
-            if e[0] == track.TEMPO:
+        for e in midieventstream:
+            if e[0] == midieventstream.TEMPO:
                 self.__driver.set_tempo(int(magic * e[2] / e[1]))
-            elif e[0] == track.NOTELEN_TIME:
+            elif e[0] == midieventstream.NOTELEN_TIME:
                 notelen = e[1]
                 #print "notelen: ", notelen
-            elif e[0] == track.NOTE_ON:
+            elif e[0] == midieventstream.NOTE_ON:
                 self.__driver.note_on(int(1000 * notelen), e[1], e[2], e[3])
                 notelen = 0
-            elif e[0] == track.NOTE_OFF:
+            elif e[0] == midieventstream.NOTE_OFF:
                 self.__driver.note_off(int(1000 * notelen), e[1], e[2], e[3])
                 notelen = 0
-            elif e[0] == track.SET_PATCH:
+            elif e[0] == midieventstream.SET_PATCH:
                 self.__driver.program_change(e[1], e[2])
-            elif e[0] == track.BENDER:
+            elif e[0] == midieventstream.BENDER:
                 print "ugh todo: seq_bender for play_with_drvmidi"
                 #m.seq_bender(DEV, e[1], e[2])
             else:
