@@ -69,7 +69,7 @@ class DocViewer(gtk.VBox):
                 self.m_loaded_file = fn
             if anchor and 'g_view' in dir(self.m_htmlwidget):
                 self.m_htmlwidget.g_view.jump_to_anchor(anchor)
-        except IOError, e:
+        except IOError:
             self.m_htmlwidget.source("<html>File not found: '%s'</html>" % fn)
     def on_anchor_track(self, url):
         if url:
