@@ -17,9 +17,6 @@
 
 from __future__ import division
 
-if __name__ == '__main__':
-    import testsetup
-
 import gtk
 import runtime
 if runtime.use_cairo_widgets:
@@ -28,7 +25,6 @@ if runtime.use_cairo_widgets:
 import mpd
 import soundcard
 import cfg
-import runtime
 
 class CairoCommon(object):
     def __init__(self):
@@ -665,20 +661,9 @@ def name_to_inputwidget(name, callback):
     elif name == _("5 string bass"):
         w = AbstractGuitarWidget(callback, ["g,", "d,", "a,,", "e,,", "b,,,"],
                                  (1, 1, 2, 3, 3))
-    elif name == _("6 string bass"):
+    else:
+        assert name == _("6 string bass")
         w = AbstractGuitarWidget(callback, ["c", "g,", "d,", "a,,", "e,,", "b,,,"],
                                  (1, 1, 2, 2, 3, 3))
-    else:#if name == _("Buttons"):
-        w = IntervalButtonsWidget(callback)
     return w
 
-if __name__ == '__main__':
-    import math
-    w = gtk.Window()
-    guitar = IntervalPianoWidget(None)
-    vbox = gtk.VBox()
-    w.add(vbox)
-    vbox.pack_start(guitar)
-    w.connect('destroy', gtk.main_quit)
-    w.show_all()
-    gtk.main()
