@@ -253,7 +253,7 @@ class MainWin(gtk.Window):
             'count': len(self.m_P.m_questions)})
         self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
     def load_file(self, filename):
-        self.m_P = lessonfile.ChordLessonfile(filename, None)
+        self.m_P = lessonfile.ChordLessonfile(filename)
         self.m_P.m_changed = False
         if self.m_P.m_questions:
             self.m_P._idx = 0
@@ -329,7 +329,7 @@ class MainWin(gtk.Window):
     def save_file(self):
         if not self.m_P.m_filename:
             raise "No filename. Cannot save."
-        ofile = file(self.m_P.m_filename, 'w')
+        ofile = open(self.m_P.m_filename, 'w')
         ofile.write("# Creator: GNU Solfege lesson file editor %s\n\n"
                     % app_version)
         ofile.write("header {\n    module = %s\n" % self.m_P.header.module)
