@@ -20,7 +20,6 @@
 copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others."
 
 import time
-t1 = time.clock()
 import sys
 import os
 import time
@@ -802,6 +801,5 @@ def start_app(prefix, datadir):
         else:
             sys.__excepthook__(t, msg, traceback)
     sys.excepthook = ef
-    print time.clock() - t1
     gtk.main()
 
