@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -65,8 +65,10 @@ class Gui(abstract.LessonbasedGui):
             self.g_play_answer.set_sensitive(True)
             self.m_t.play_440hz()
         except Exception, e:
+            e.m_mpd_varname = 'music'
+            e.m_mpd_badcode = self.m_t.m_P.get_question()['music'].m_musicdata
             if not self.standard_exception_handler(e, __file__, exception_cleanup):
-                raise e
+                raise
     def on_start_practise(self):
         self.update_gui_after_lessonfile_change()
         # if we have not m_P, then parsing of the lessonfile failed,
