@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import re
 import sys
 import gtk
 import cfg
@@ -30,6 +29,8 @@ class AbstractQuestionNameTable(gtk.Table, cfg.ConfigUtils):
         gtk.Table.__init__(self)
         cfg.ConfigUtils.__init__(self, exname)
         self._ignore_watch = 0
+        # will be defined in subclasses. Set to none to please pychecker.
+        self.ask_for_names_changed = None
         self.add_watch('ask_for_names', self.ask_for_names_changed)
     def initialize(self, num, dir):
         self.m_num = num
