@@ -19,15 +19,10 @@
 # Remember to increase statistics_version and add code to handle
 # old versions if incompatabilities are added.
 
-if __name__ == '__main__':
-    import testsetup
-
 import sys
 import time, os, pickle
-import shutil
 import utils
 import gethomedir
-import configureoutput
 
 # version 1, the first version was introduced with Solfege 2.0
 # version 2 was introduced in the newxercisesetup changes
@@ -39,7 +34,7 @@ STATISTICS_SAVE_DIR = os.path.join(gethomedir.get_home_dir(), '.solfege',
 if not os.path.exists(STATISTICS_SAVE_DIR):
     if not os.path.exists(STATISTICS_SAVE_DIR):
         os.makedirs(STATISTICS_SAVE_DIR)
-    f = file(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'w')
+    f = open(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'w')
     print >> f, statistics_version
     f.close()
 
@@ -49,7 +44,7 @@ def get_statistics_version():
     STATISTICS_SAVE_DIR has.
     """
     try:
-        f = file(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'r')
+        f = open(os.path.join(STATISTICS_SAVE_DIR, 'statistics_version'), 'r')
     except IOError, e:
         print >> sys.stderr, "While opening the file '%s':" % os.path.join(STATISTICS_SAVE_DIR, 'statistics_version')
         print >> sys.stderr, e
@@ -204,20 +199,6 @@ class AbstractStatistics:
         self.m_session_stat = {}
 
 
-class Statistics(AbstractStatistics):
-    def __init__(self, teacher):
-        AbstractStatistics.__init__(self, teacher)
-        self.load_statistics(self.m_savepath)#FIXME newexercisesetup update
-    def save_data(self):
-        raise "NewExerciseSetup update"
-        if not usable_statistics:
-            return
-        if self.m_session_stat:
-            f = open(os.path.join(self.m_savepath, str(int(time.time()))), 'w')
-            pickle.dump(self.m_session_stat, f)
-            f.close()
-
-
 class LessonStatistics(AbstractStatistics):
     def __init__(self, teacher):
         AbstractStatistics.__init__(self, teacher)
@@ -316,5 +297,3 @@ class HarmonicIntervalStatistics(LessonStatistics):
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(key, 1, 0)
 
-if __name__ == '__main__':
-    print "statistics_version:", get_statistics_version()
