@@ -15,8 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gu
-import os
+import gtk
+import gu
 
 
 class MatrixTable(gtk.VBox):
