@@ -207,10 +207,10 @@ class TrainingSetDialog(gtk.Window):
                     i.connect('activate', self.on_select_exercise)
                     menu.append(i)
                 return menu
-            item = gtk.MenuItem(menudata['name'])
+            item = gtk.MenuItem(_(menudata['name']))
             menu = gtk.Menu()
             for m in menudata['children']:
-                i = gtk.MenuItem(m['name'])
+                i = gtk.MenuItem(_(m['name']))
                 menu.append(i)
                 i.set_submenu(create_submenu(m['children'], parent_name + [_(m['name'])]))
             item.set_submenu(menu)
