@@ -15,18 +15,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-if __name__ == '__main__':
-    import testsetup
-
 import urlparse
-import os
 import gtk
 import re, math
 import mpd
 import const
 import random
 import soundcard, cfg
-import unittest
 
 def mangle_email(email):
     email = email.replace("@", " ,, ")
@@ -234,7 +229,6 @@ def compare_version_strings(A, B):
     return 0
 
 class Url:
-    __test__ = ">>> True"
     def __init__(self, href):
         self.href = href
         self.protocol, loc, path, params, query, self.anchor = urlparse.urlparse(self.href)
@@ -251,20 +245,3 @@ class Url:
             if self.config:
                 self.config = _str_to_dict(self.config)
 
-class TestUrlClass(unittest.TestCase):
-    def setUp(self):
-        pass
-    def test_all(self):
-        url = Url('solfege:practise/lesson-files/melodic-intervals?ask_for_names=[1, 2, 3]')
-        self.assert_(url.protocol == 'solfege')
-        self.assert_(url.action == 'practise')
-        self.assert_(url.lessonfile == 'lesson-files/melodic-intervals')
-        self.assert_(url.config == {'ask_for_names': '[1, 2, 3]'})
-        url = Url('solfege://home/tom/lessonfiles/melodic-intervals?ask_for_names=[1, 2, 3]')
-        self.assert_(url.protocol == 'solfege')
-        self.assert_(url.lessonfile == '/home/tom/lessonfiles/melodic-intervals')
-        self.assert_(url.config == {'ask_for_names': '[1, 2, 3]'})
-
-
-if __name__ == '__main__':
-    unittest.main()
