@@ -106,7 +106,7 @@ def _get_random_reader():
         try:
             import random
             try:
-                _random_reader = file("/dev/urandom","rb").read
+                _random_reader = open("/dev/urandom","rb").read
             except:
                 _random_reader = os.fdopen(os.open("/dev/random",os.O_RDONLY|os.O_NONBLOCK),"rb").read
             sec,usec = _gettimeofday()
@@ -373,7 +373,7 @@ def linux_generate():
     """Generate a UUID by reading from /proc/sys/kernel/random/uuid.
     This will raise an exception if we are not on Linux
     """
-    f = file('/proc/sys/kernel/random/uuid')
+    f = open('/proc/sys/kernel/random/uuid')
     s = f.readline().strip()
     f.close()
     return s
