@@ -1,3 +1,4 @@
+from __future__ import division
 # GNU Solfege - free ear training software
 # Copyright (C) 2005, 2007 Tom Cato Amundsen
 #
@@ -15,7 +16,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-from __future__ import division
 import random
 import cfg
 
@@ -111,12 +111,3 @@ class Random(object):
         if len(self.m_last_choices) > len(self.m_choices) * 2:
             self.m_last_choices.pop(0)
 
-
-def main():
-    r = Random((1, 2, 3))
-    r.m_count = 8
-    r.m_choice_count = [3, 3, 2]
-    print r.select2()
-
-if __name__ == '__main__':
-    main()
