@@ -8,6 +8,9 @@ import unittest
 import glob
 import os
 
+ok_different_mapping_key = (
+  "notenameformat|%(notename)s%(oct)s",
+)
 class Entry(object):
     # translated status: UNTRANS, FUZZY, TRANS
     # obsolete: True / False
@@ -138,12 +141,23 @@ def find_string_formatting(s):
     m = r.search(s[start:])
     ret = []
     while m:
-        #print "->", start, m, start + m.start(), start + m.end(), m.group()
         ret.append(m.group())
         start = start + m.end()
         m = r.search(s[start:])
     return ret
 
+def find_string_formatting_mapping_keys(s):
+    s = re.sub("%\s*%", "", s)
+    r = re.compile("\%(\((?P<name>\w*)\))?(?P<notname>(\.?\d+)?[^\s\(])")
+    start = 0
+    m = r.search(s[start:])
+    ret = []
+    while m:
+        ret.append((m.group('name'), m.group('notname')))
+        start = start + m.end()
+        m = r.search(s[start:])
+    return ret
+
 class TestFindStringFormatting(unittest.TestCase):
     def test_simplest(self):
         for n in ("%s", "%f", "%.2d", "%03d"):
@@ -171,6 +185,12 @@ Požadované skóre bylo%.1f% %.
 """
         self.assertEqual(find_string_formatting(msgid),
                          find_string_formatting(msgstr))
+    def test_mapping(self):
+        v1 = find_string_formatting_mapping_keys("%(name)s %(bla).1f X")
+        v2 = find_string_formatting_mapping_keys("%(bla).1f X X %(name)s ")
+        v1.sort()
+        v2.sort()
+        self.assertEqual(v1, v2)
 
 
 def check_file(filename):
@@ -190,6 +210,16 @@ def check_file(filename):
             print "%s != %s" % (a, b)
             print "Entry status:", entry.get_status()
             print
+        # Check mapping key
+        v1 = find_string_formatting_mapping_keys(entry.get_msgid())
+        v2 = find_string_formatting_mapping_keys(entry.get_msgstr())
+        if (v1 != v2) and entry.get_msgstr() \
+                and (entry.get_status() not in ('obsolete', 'fuzzy')) \
+                and (entry.get_msgid() not in ok_different_mapping_key):
+            file_ok = False
+            print "Mapping key not equal in the file", filename
+            print "\tmsgid: \"" + entry.get_msgid() + "\""
+            print "\tmsgstr: \"" + entry.get_msgstr() + "\""
         # Check for notename| strings
         if entry.get_msgid().startswith("notename|"):
             if "|" in entry.get_msgstr():
